@@ -7,7 +7,7 @@ class Controller(object):
     def register_view(self, view):
         self._view = view
     
-    def on_quit(self, sender):
+    def on_quit(self, *args):
         raise NotImplementedError
 
     def on_keybinding_activated(self, core, time):
@@ -47,7 +47,4 @@ class Controller(object):
         raise NotImplementedError
     
     def on_history_match_selected(self, history, text, match):
-        raise NotImplementedError
-    
-    def update_entry_icon (self, icon=None):
         raise NotImplementedError
\ No newline at end of file
