@@ -17,6 +17,7 @@ class CuemiacWindowView(AbstractCuemiacView, gtk.Window):
         self.connect("configure-event", self.__save_window_size)
         self.connect("delete-event", self._controller.on_quit)
         self.connect("destroy-event", self._controller.on_quit)
+        self.connect("focus-out-event", self._controller.on_quit) 
         self.connect("key-press-event", self.__on_window_key_press_event)
        
         self.set_title("Deskbar Applet")
@@ -25,14 +26,14 @@ class CuemiacWindowView(AbstractCuemiacView, gtk.Window):
         self.set_role("deskbar-search-window")
         self.set_property("skip-taskbar-hint", True)
 
+        # Reset width to default
+        self.get_entry().set_width_chars(-1)
+
         self.add(self.vbox_main)
 
         # Search entry
         self.vbox_main.pack_start(self.header, False)
         
-        # History TreeView
-        self.vbox_main.pack_start(self.history_box, False)
-        
         # Results
         self.results_box = gtk.HBox()
         self.results_box.connect("unmap", self.__save_window_height)
@@ -52,11 +53,11 @@ class CuemiacWindowView(AbstractCuemiacView, gtk.Window):
         return self
     
     def receive_focus(self, time):
+        self.move( self._model.get_window_x(), self._model.get_window_y() )
         self.entry.grab_focus()
         self.realize()
         self.window.set_user_time(time)
         self.present()
-        self.move( self._model.get_window_x(), self._model.get_window_y() )
     
     def show_results(self):
         AbstractCuemiacView.show_results(self)
